<?php


namespace Drupal\fillpdf\Tests;

use Drupal\file\Tests\FileManagedTestBase;

/**
 * Ensure Edit links for PDFs at /admin/structure/fillpdf function correctly.
 *
 * @ingroup fillpdf
 *
 * @group FillPDF
 */
class FillPdfAdminIdTest extends FileManagedTestBase {

  static public $modules = ['fillpdf_test'];
  protected $profile = 'minimal';

  protected function setUp() {
    parent::setUp();

    // Create and log in our privileged user.
    $account = $this->drupalCreateUser([
      'access administration pages',
      'administer pdfs',
    ]);
    $this->drupalLogin($account);
  }

  public function testEditLink() {
    // fillPDF needs to be configured.
    $this->container->get('config.factory')
      ->getEditable('fillpdf.settings')
      ->set('scheme', 'public')
      ->set('backend', 'test')
      ->save();

    // Upload a test file.
    $edit = array(
      'files[upload_pdf]' => drupal_get_path('module', 'fillpdf') . '/tests/modules/fillpdf_test/files/fillpdf_test_v3.pdf',
    );
    $this->drupalPostForm('admin/structure/fillpdf', $edit, 'Upload');
    $this->assertResponse(200, 'Received a 200 response for posted test file.');
    // Get the fid of the uploaded file to construct the link.
    // @todo: This should be an entity query.
    $max_fid_after = db_query('SELECT MAX(fid) AS fid FROM {file_managed}')->fetchField();
    $this->drupalGet('admin/structure/fillpdf/' . $max_fid_after);
    $this->assertResponse(200, 'Received a 200 response for fillPDF Edit link.');
  }

}
